/* /////////////////////////////////////////////////////////////////////////////
 * File:		types.d
 *
 * Purpose:		Win32 basic types
 *
 * Created		15th September 2003
 * Updated:		15th September 2003
 *
 * Copyright:	Synesis Software Pty Ltd, (c) 2002. All rights reserved.
 *
 * Home:		http://www.synesis.com.au/software
 *
 * ////////////////////////////////////////////////////////////////////////// */



/** \file synsoft/win32/types.d This file contains Win32 types */

/* ////////////////////////////////////////////////////////////////////////// */

module synsoft.win32.types;

/* ////////////////////////////////////////////////////////////////////////// */

/// \defgroup group_synsoft_win32_types synsoft.win32.types
/// \ingroup group_synsoft_win32
/// \brief This library provides Win32 types

/* ////////////////////////////////////////////////////////////////////////// */


////////////////////////////////////////////////////////////////////////////////
// Special types

/// Used for reserved parameters
///
/// \ingroup group_synsoft_win32_types
public typedef uint					Reserved;

/// Represents a boolean quantity
///
/// \ingroup group_synsoft_win32_types
public alias int					BOOL;

////////////////////////////////////////////////////////////////////////////////
// Handle types

/// Represents an untyped handle
///
/// \ingroup group_synsoft_win32_types
public typedef void					*HANDLE;
/// Pointer to an untyped handle
///
/// \ingroup group_synsoft_win32_types
public alias HANDLE					*LPHANDLE;

/// Represents a registry key handle
///
/// \ingroup group_synsoft_win32_types
public typedef	void	*HKEY;
/// Pointer to a registry key handle
///
/// \ingroup group_synsoft_win32_types
alias	HKEY	*PHKEY;


////////////////////////////////////////////////////////////////////////////////
// Integral types

/// Represents a byte
///
/// \ingroup group_synsoft_win32_types
public alias byte					BYTE;
/// Pointer to a byte
///
/// \ingroup group_synsoft_win32_types
public alias BYTE					*LPBYTE;

/// Represents a 32-bit signed integer
///
/// \ingroup group_synsoft_win32_types
public alias int					LONG;
/// Pointer to a 32-bit signed integer
///
/// \ingroup group_synsoft_win32_types
public alias LONG					*LPLONG;

/// Represents an unsigned integer
///
/// \ingroup group_synsoft_win32_types
public alias uint					UINT;
/// Pointer to an unsigned integer
///
/// \ingroup group_synsoft_win32_types
public alias UINT					*LPUINT;

/// Represents a 32-bit unsigned integer
///
/// \ingroup group_synsoft_win32_types
public alias uint					DWORD;
/// Pointer to a 32-bit unsigned integer
///
/// \ingroup group_synsoft_win32_types
public alias DWORD					*LPDWORD;

////////////////////////////////////////////////////////////////////////////////
// Pointer types

/// Opaque pointer
///
/// \ingroup group_synsoft_win32_types
public alias void					*LPVOID;
/// Opaque pointer
///
/// \ingroup group_synsoft_win32_types
public alias void					*LPCVOID;

////////////////////////////////////////////////////////////////////////////////
// Character string types

/// Pointer to an ANSI character string
///
/// \ingroup group_synsoft_win32_types
public alias char					*LPSTR;
/// Pointer to an ANSI character string
///
/// \ingroup group_synsoft_win32_types
public alias char					*LPCSTR;

/// Pointer to a Unicode character string
///
/// \ingroup group_synsoft_win32_types
public alias wchar					*LPWSTR;
/// Pointer to a Unicode character string
///
/// \ingroup group_synsoft_win32_types
public alias wchar					*LPCWSTR;

////////////////////////////////////////////////////////////////////////////////
// Specific types

public alias void					*LPSECURITY_ATTRIBUTES;
/// Contains the security descriptor for an object and specifies whether the handle retrieved by specifying this structure is inheritable
///
/// \ingroup group_synsoft_win32_types
public struct						SECURITY_ATTRIBUTES
{ 
	/// The size, in bytes, of this structure
	DWORD	nLength;
	/// Pointer to a security descriptor for the object that controls the sharing of it. If NULL is specified for this member, the object is assigned the default security descriptor of the calling process. This is not the same as granting access to everyone by assigning a null DACL. The default security descriptor is based on the default DACL of the access token belonging to the calling process. By default, the default DACL in the access token of a process allows access only to the user represented by the access token. If other users must access the object, you can either create a security descriptor with a null DACL, or add ACEs to the DACL that grants access to a group of users
	LPVOID	lpSecurityDescriptor;
	/// Specifies whether the returned handle is inherited when a new process is created. If this member is TRUE, the new process inherits the handle
	BOOL	bInheritHandle;
};
public alias SECURITY_ATTRIBUTES	*PSECURITY_ATTRIBUTES; 

/// A 64-bit value representing the number of 100-nanosecond intervals since January 1, 1601 (UTC).
///
/// \ingroup group_synsoft_win32_types
public struct FILETIME
{
	/// Specifies the low-order 32 bits of the file time
    DWORD	dwLowDateTime;
	/// Specifies the high-order 32 bits of the file time
    DWORD	dwHighDateTime;	
};


/* ////////////////////////////////////////////////////////////////////////// */
